Tilt Sensor
===========

|location_link|

.. |location_link| raw:: html

   <a href="https://www.bricklink.com/catalogItemInv.asp?S=45305-1" target="_blank">BrickLink item</a>

.. autoclass:: buildhat.TiltSensor
   :members:
   :inherited-members:

Example
-------

.. literalinclude:: tilt.py


